@@ -15,7 +15,7 @@ __author__ = "Ali Onur Uyar"
 __copyright__ = "Copyright 2011, Ali Onur Uyar"
 __credits__ = ["Samuel Stauffer"]
 __license__ = "GPL"
-__version__ = "0.9.9"
+__version__ = "0.9.11"
 __maintainer__ = "Ali Onur Uyar"
 __email__ = "aouyar at gmail.com"
 __status__ = "Development"
@@ -822,12 +822,12 @@ def muninMain(pluginClass, argv=None, env=None, debug=False):
             return 0
         else:
             return 1
-    except Exception, msg:
+    except Exception, e:
+        print >> sys.stderr, "EXCEPTION: %s" % str(e)
         if debug:
             raise
         else:
-            print >> sys.stderr, "EXCEPTION: %s" % msg
-        return 1
+            return 1
 
 
 def fixLabel(label, maxlen, delim=None, repl='', truncend=True):
